pub struct GrpcWebBridge(/* private fields */);Expand description
gRPC-web bridge module, this will convert HTTP/1.1 gRPC-web requests to H2 gRPC requests
Methods from Deref<Target = GrpcWebCtx>
pub fn init(&mut self)
Sourcepub fn request_header_filter(&mut self, req: &mut RequestHeader)
pub fn request_header_filter(&mut self, req: &mut RequestHeader)
gRPC-web request is fed into this filter, if the module is initialized we attempt to convert it to a gRPC request
Sourcepub fn response_header_filter(&mut self, resp: &mut ResponseHeader)
pub fn response_header_filter(&mut self, resp: &mut ResponseHeader)
gRPC response is fed into this filter, if the module is in the bridge state attempt to convert the response it to a gRPC-web response