Module utils

Module utils 

This module contains various types that make it easier to work with bytes and X509 certificates.

Modules

tls

Structs

BufRef
A BufRef is a reference to a buffer of bytes. It removes the need for self-referential data structures. It is safe to use as long as the underlying buffer does not get mutated.
KVRef
A KVRef contains a key name and value pair, stored as two BufRef types.

Constants

EMPTY_KV_REF
A KVRef which contains empty sub-slices.